# Example from the slide expressed in AMPL language

# Define parameters

param w1 := 100;
param w2 := 200;
param E := 30;

# Define variables and their bounds

var c{j in 1..2} >= 0 <= w2;
var n{j in 1..2} >= 0 <= 1;
var t >= 0 <= 1;
var T >= 0 <= w1 + w2;
var slack{j in 1..2} >= 0;

# Objective function to be minimized.

minimize obj: -(log(c[1]*(1 - n[1])) + c[2] - 1/(1 - n[2]));

# budget constraints

s.t. budget1: c[1] = (1 - t)*w1*n[1] + T;
s.t. budget2: c[2] = (1 - t)*w2*n[2] + T;
s.t. budgetG: t*(w1*n[1] + w2*n[2]) = E + 2*T;

# Define slack variables
s.t. def_slack1: slack[1] = 1/(1 - n[1]) - (1 - t)*w1/(c[1]);
s.t. def_slack2: slack[2] = 1/(1 - n[2])^2 - (1 - t)*w2;

# Complementarity constraints
s.t. compl1: 0 <= n[1] complements slack[1] >= 0;
s.t. compl2: 0 <= n[2] complements slack[2] >= 0;

# Define initial point.

let c[1] := w2/2;
let c[2] := w2/2;
let n[1] := 0.6;
let n[2] := 0.6;
let t := 0.1;
let T := 10;
let slack[1] := 0;
let slack[2] := 0;

# Use knitro
option solver knitroampl;